==> bcc-core-api-node-sdk-1.12.0.tgz: package/lib/esm/api/genericClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from "axios";
import { ObjectSerializer } from "../api.js";
import { CoreApiError } from "../model/error.js";
import { serializeFindQueryParams, serializeGetQueryParams, } from "../model/queryParams.js";
export class GenericClient {
    constructor(config) {
        this.config = config;
        this.httpClient = axios.create({
            validateStatus: () => true,
        });
    }
    create(data) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath;
            const res = yield this.httpClient.post(url, ObjectSerializer.serialize(data, this.config.writeTypeName), {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    get(id, getParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            getParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), getParams.options);
            const queryParams = serializeGetQueryParams(getParams);
            const url = this.config.basePath +
                this.config.endpointPath +
                "/" +
                id +
                "?" +
                queryParams;
            const res = yield this.httpClient.get(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            findParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), findParams.options);
            const queryParams = serializeFindQueryParams(findParams);
            const url = this.config.basePath + this.config.endpointPath + "?" + queryParams;
            const res = yield this.httpClient.get(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.multipleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    patch(id, data) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath + "/" + id;
            const res = yield this.httpClient.patch(url, JSON.stringify(ObjectSerializer.serialize(data, this.config.patchTypeName)), {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath + "/" + id;
            const res = yield this.httpClient.delete(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
}

==> bcc-core-api-node-sdk-1.16.0.tgz: package/lib/esm/api/genericClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from "axios";
import { ObjectSerializer } from "../api.js";
import { CoreApiError } from "../model/error.js";
import { serializeFindQueryParams, serializeGetQueryParams, } from "../model/queryParams.js";
export class GenericClient {
    constructor(config) {
        this.config = config;
        this.httpClient = axios.create({
            validateStatus: () => true,
        });
    }
    create(data) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath;
            const res = yield this.httpClient.post(url, ObjectSerializer.serialize(data, this.config.writeTypeName), {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    get(id, getParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            getParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), getParams.options);
            const queryParams = serializeGetQueryParams(getParams);
            const url = this.config.basePath +
                this.config.endpointPath +
                "/" +
                id +
                "?" +
                queryParams;
            const res = yield this.httpClient.get(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            findParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), findParams.options);
            const queryParams = serializeFindQueryParams(findParams);
            const url = this.config.basePath + this.config.endpointPath + "?" + queryParams;
            const res = yield this.httpClient.get(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.multipleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    update(id, data) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath + "/" + id;
            const res = yield this.httpClient.put(url, JSON.stringify(ObjectSerializer.serialize(data, this.config.writeTypeName)), {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath + "/" + id;
            const res = yield this.httpClient.delete(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
}
